@@ -620,8 +620,12 @@ void CallManager::get_video_options (CallManager::VideoOptions & options) const
 OpalCall *CallManager::CreateCall ()
 {
   gmref_ptr<Ekiga::CallCore> call_core = core.get ("call-core"); // FIXME: threaded?
+  gmref_ptr<Opal::Call> call;
 
-  gmref_ptr<Opal::Call> call (new Opal::Call (*this, core));
+  if (uri != 0)
+    call = gmref_ptr<Opal::Call> (new Opal::Call (*this, core, (const char *) uri));
+  else
+    call = gmref_ptr<Opal::Call> (new Opal::Call (*this, core, ""));
   call_core->add_call (call, gmref_ptr<CallManager>(this));
 
   return call.get ();
